@@ -14,7 +14,7 @@ L<https://github.com/iafan/Config-Neat>
 
 package Config::Neat::Util;
 
-our $VERSION = '0.6';
+our $VERSION = '0.7';
 
 use strict;
 
@@ -24,6 +24,7 @@ our @ISA = qw(Exporter);
 
 our @EXPORT_OK = qw(
     new_ixhash
+    to_ixhash
     is_number
     is_code
     is_hash
@@ -50,6 +51,14 @@ sub new_ixhash {
     return $new;
 }
 
+sub to_ixhash {
+    my $node = shift;
+    die "Not a regular hash" unless is_hash($node) && !is_ixhash($node);
+    my $new = new_ixhash;
+    map { $new->{$_} = $node->{$_} } keys %$node;
+    return $new;
+}
+
 sub is_number {
     my $n = shift;
     return ($n + 0) eq $n;
